# Decisions Concerning the UDB
The following are decisions that have been made concerning the UDB. This is not a comprehensive list, but it is here to help those who might wonder why the UDB is as it is.
## UDB Style
The following are details concerning the use  of punctuation, capitalization, and vocabulary in the UDB.
  * Quotation marks are used at the beginning and ending of direct speech. They are not used at the beginning of each verse, even though the speech may span several verses.
  * Contractions are not used in the ULB.
  * Punctuation is normally (not always) inside the quotation marks.
  * Capitalization issues: in general, we follow the practice of the 2011 NIV.
  * Titles are capitalized. (Son of Man, King David, the Christ)
  * All pronouns, even those referring to God, are lower case (except when beginning sentences and except for the first singular "I").
  * Spelling of names, in most cases, follows that used in the 2011 NIV.
  * Where possible, the UDB editors have used common vocabulary that is easy to translate into another language.

## Avoiding Translation Difficulties
The primary goal of the UDB is to express the meaning of the Bible as clearly as possible. In order to do this, it follows these guidelines.

The UDB avoids as much as reasonably possible:
1. Idioms
2. Figures of speech
3. Events out of order
4. Difficult or specialized grammar  
    a. Complex sentences  
    b. Passive voice  
    c. Abstract or verbal nouns  
    d. People speaking of themselves in third person  
    
The UDB explicitly includes:  
1. Participants where these are unclear  
2. Implied information that is necessary for understanding

### Examples
The following are examples of ways that the text of the Bible can be unclear for some languages and what the UDB does to overcome those problems. 
#### Passive Voice
Passive voice is a grammatical construction that is common in Greek and English but it is not used in many other languages, so it can be very confusing. For that reason, it is not used in the UDB. In passive voice, the receiver of the action changes places with the actor. In English, the actor normally comes first in the sentence. But in passive voice, the receiver of the action comes first. Often, the actor is left unstated. In that case, the UDB will fill in the actor. See "Missing Participants" below.
For example, the ULB of Romans 2:24 says:  
"the name of God is blasphemed  among the Gentiles because of you."  
The action is "blaspheme," the actors are "the Gentiles" (non-Jews), and the receiver of the action is "the name of God." The reason for the action is "because of you." The UDB rearranges the verse to put the actor and the receiver of the action in a more normal order.
The UDB of Romans 2:24 says:  
"Because of the evil things that you Jews do, the non-Jews say insulting things about God."
#### Abstract Nouns
The UDB uses verbs and adjectives instead of abstract nouns when it does not make the phrase overly complex.
The ULB of Romans 2:10 says:  
"But praise, honor, and peace will come to everyone who practices good..."  
In this verse, the words "praise," "honor," "peace," and "good" are abstract nouns. That is, they are words that refer to things that we cannot see or touch. They are ideas. The ideas that these nouns express are closer to actions or descriptions than they are to things. In many languages, therefore, these ideas must be expressed by verbs or description words, not by nouns. For this reason, the UDB expresses these nouns as actions or descriptions.
The UDB of Romans 2:10 says:  
"But God will praise, honor, and give a peaceful spirit to every person who habitually does good deeds."
#### Long, Complex Sentences
The UDB avoids using long or complex sentences. In many languages, long or complex sentences are unnatural and unclear.
The ULB translates the first three verses of Romans as one complex sentence. It says:  
"1 Paul, a servant of Jesus Christ, called to be an apostle and set apart for the gospel of God, 2 which he promised beforehand by his prophets in the holy scriptures, 3 concerning his Son, who was a descendant of David according to the flesh."
The UDB breaks that into five sentences that are more simple in form. It says:  
"1 I, Paul, who serve Christ Jesus, am writing this letter to all of you believers in the city of Rome. God chose me to be an apostle, and he appointed me in order that I should proclaim the good news that comes from him. 2 Long before Jesus came to earth, God promised that he would reveal this good news by means of what his prophets wrote in the sacred scriptures. 3 This good news is about his Son. As to his Son's physical nature, he was born a descendant of King David."
#### Missing Participants
The UDB often fills in the participants when these are lacking in the original Bible and the ULB. In the original biblical languages, these participants could be left out and still understood by the reader. But in many languages these must be included for the translation to be clear and natural.
In the ULB, Romans 1:1 says:  
"Paul, a servant of Jesus Christ, called to be an apostle, set apart for the gospel of God..."
In this verse, there is a participant that is left unstated, but still understood. This participant is God. It is God who called Paul to be an apostle and who set him apart for the Gospel. In some languages, this participant must be stated.
Therefore the UDB of Romans 1:1 says:  
"God chose me to be an apostle, and he appointed me in order that I should proclaim the good news that comes from him."
#### Events out of Order
The UDB often tells about events in the order they happened.
The ULB of Luke 2:6-7 says:  
"6 Now it came about that while they were there, the time came for her to deliver her baby. 7 She gave birth to a son, her firstborn child, and she wrapped him in long strips of cloth and laid him in a manger, because there was no room for them in the inn."
In some languages, events need to be told in the order in which they happened, or else the story will be confusing and hard to understand. People might understand from these verses that Mary delivered her baby outside in the street, and then looked for somewhere to stay and, after a long search, ended up putting him in an animal feeding trough. The UDB tells these events in the order in which they happened, so that it is clear that Mary was already in the shelter for animals when she gave birth.
The UDB says:  
"6-7 When they arrived in Bethlehem, there was no place for them to stay in a place where visitors usually stayed. So they had to stay in a place where animals slept overnight. While they were there the time came for Mary to give birth and she gave birth to her first child, a son. She wrapped him in wide strips of cloth and laid him down where the food was kept for the animals inside the barn."
#### Figures of Speech
The UDB expresses the meanings of the scripture without using figures of speech.
The ULB of Romans 2:21 says:  
"You who preach against stealing, do you steal?"
This is a figure of speech called a rhetorical question. It is not a real question that is used to seek an answer. It is used to make a point. In this case, Paul is using it to scold his audience and to condemn their hypocrisy. Many languages do not use rhetorical questions, or they do not use them in this way.
To show how to translate this meaning without a rhetorical question, the UDB says:  
"You who preach that people should not steal things, it is disgusting that you yourself steal things!"
#### Idioms
The UDB expressing the meanings of the scripture without using idioms.
The ULB of Deuteronomy 32:10 says:  
"he guarded him as the apple of his eye."
The word "apple" here does not refer to a kind of fruit, but instead refers to the pupil, the dark center of a person's eye. The phrase "the apple of his eye" is an idiom that refers to anything that is extremely precious to a person, or the one thing that is the most precious to a person. In many languages this idiom makes no sense.
To show the meaning of this verse, the UDB expresses this in plain language, without an idiom.
The UDB says:
"He protected them and took care of them, as every person takes good care of his own eyes."
The translationNotes add another way to translate this that makes the meaning clear. It says, "He protected the people of Israel as something most valuable and precious."
#### People Speaking of Themselves in Third Person
THe UDB uses first person pronouns when people speak about themselves.
The ULB of Genesis 18:3 says:  
He said, "My Lord, if I have found favor in your sight, please do not pass by your servant."
Here Abraham refers to himself in the third person as "your servant." To make it clear that Abraham is referring to himself, the UDB adds the first person pronoun "me."
The UDB of Genesis 18:3 says:
He said to one of them, "Lord, if you are pleased with me, stay here with me, your servant, for a little while."
#### Implied Information
The UDB make explicit any information that is needed for a clear understanding of the text.
The ULB of Mark 1:44 says:  
He said to him, "Be sure to say nothing to anyone, but go, show yourself to the priest, and offer for your cleansing what Moses commanded, as a testimony to them."
This was all that Jesus needed to say to the man whom he had just healed of leprosy, because the man was Jewish and knew all about the laws concerning being clean and unclean. But most modern readers of our Bible translations do not know that information. For that reason, the UDB makes this information explicit that was left implied in the text. This information is indicated in italics below.
The UDB of Mark 1:44 says:
UDB: He said, "Do not tell anyone *what just happened*. Instead, go to a priest and show yourself to him *in order that he may examine you and see that you no longer have leprosy*. Then make the offering that Moses commanded *for people whom God has healed from leprosy*. This will be the testimony to *the community that you are healed*."